@@ -8,17 +8,17 @@ from .app import _get_current_app, App
 
 
 def init_app(app, app_id: str = None) -> Callable[[], Optional[App]]:
-    app.config['SESSION_PERMANENT'] = True
-    app.config['SESSION_TYPE'] = 'filesystem'
-    app.config['SESSION_COOKIE_SAMESITE'] = "None"
-    app.config['SESSION_COOKIE_SECURE'] = True
-    app.config['SESSION_COOKIE_PATH'] = "/"
+    app.config["SESSION_PERMANENT"] = True
+    app.config["SESSION_TYPE"] = "filesystem"
+    app.config["SESSION_COOKIE_SAMESITE"] = "None"
+    app.config["SESSION_COOKIE_SECURE"] = True
+    app.config["SESSION_COOKIE_PATH"] = "/"
 
-    app.config['PERMANENT_SESSION_LIFETIME'] = timedelta(hours=5)
+    app.config["PERMANENT_SESSION_LIFETIME"] = timedelta(hours=5)
 
     # The maximum number of items the session stores
     # before it starts deleting some, default 500
-    app.config['SESSION_FILE_THRESHOLD'] = 100
+    app.config["SESSION_FILE_THRESHOLD"] = 100
 
     sess = Session()
     sess.init_app(app)
@@ -27,7 +27,7 @@ def init_app(app, app_id: str = None) -> Callable[[], Optional[App]]:
         if not has_request_context():
             return None
 
-        if 'teamtv_app' not in g:
+        if "teamtv_app" not in g:
             return None
 
         return g.teamtv_app
@@ -35,11 +35,7 @@ def init_app(app, app_id: str = None) -> Callable[[], Optional[App]]:
     @app.before_request
     def reset_app():
         g.teamtv_app = _get_current_app(
-            app_id=app_id,
-            session=session,
-            token=request.args.get('token')
+            app_id=app_id, session=session, token=request.args.get("token")
         )
 
     return get_current_app
-
-
