@@ -23,28 +23,26 @@ def pol2cart(angle: float, distance: float):
 
 
 class ObservationLog(List[Observation]):
-    def __init__(self,
-                 content_class: Type[Observation],
-                 requester: Requester,
-                 method: str,
-                 url: str,
-                 clock_id: str,
-                 sporting_event: 'SportingEvent'
-                 ):
+    def __init__(
+        self,
+        content_class: Type[Observation],
+        requester: Requester,
+        method: str,
+        url: str,
+        clock_id: str,
+        sporting_event: "SportingEvent",
+    ):
         super().__init__(content_class, requester, method, url)
         self._clock_id = clock_id
         self._sporting_event = sporting_event
 
     def get_mapping_stats(self):
-        stats = dict(
-            success=0,
-            failed=0
-        )
+        stats = dict(success=0, failed=0)
         for observation in self:
             if observation.clock_id == self._clock_id:
-                stats['success'] += 1
+                stats["success"] += 1
             else:
-                stats['failed'] += 1
+                stats["failed"] += 1
         return stats
 
     def to_pandas(self):
@@ -54,25 +52,36 @@ class ObservationLog(List[Observation]):
             raise Exception("You don't have pandas installed. Please install first")
 
         observations = []
-        skip_attributes = {"teamId", "personId", "team", "person", "inPerson", "inPersonId", "outPerson", "outPersonId"}
+        skip_attributes = {
+            "teamId",
+            "personId",
+            "team",
+            "person",
+            "inPerson",
+            "inPersonId",
+            "outPerson",
+            "outPersonId",
+        }
         team = dict()
         for observation in self:
-            if observation.code == 'START-POSSESSION':
+            if observation.code == "START-POSSESSION":
                 team = dict(
-                    team_id=observation.attributes['teamId'],
-                    team_name=observation.attributes['team']['name'],
-                    team_ground=observation.attributes['team']['ground'],
-                    position=observation.attributes['position']
+                    team_id=observation.attributes["teamId"],
+                    team_name=observation.attributes["team"]["name"],
+                    team_ground=observation.attributes["team"]["ground"],
+                    position=observation.attributes["position"],
                 )
             else:
-                if 'person' in observation.attributes:
+                if "person" in observation.attributes:
                     person = dict(
-                        person_id=observation.attributes['personId'],
-                        first_name=observation.attributes['person']['firstName'],
-                        last_name=observation.attributes['person']['lastName'],
-                        number=observation.attributes['person']['number']
+                        person_id=observation.attributes["personId"],
+                        first_name=observation.attributes["person"]["firstName"],
+                        last_name=observation.attributes["person"]["lastName"],
+                        number=observation.attributes["person"]["number"],
+                    )
+                    person["full_name"] = (
+                        person["first_name"] + " " + person["last_name"]
                     )
-                    person['full_name'] = person['first_name'] + ' ' + person['last_name']
                 else:
                     person = dict()
 
@@ -83,9 +92,9 @@ class ObservationLog(List[Observation]):
                     if k not in skip_attributes:
                         attributes[k] = v
 
-                if 'angle' in attributes and 'distance' in attributes:
-                    attributes['x'], attributes['y'] = pol2cart(
-                        attributes['angle'], attributes['distance']
+                if "angle" in attributes and "distance" in attributes:
+                    attributes["x"], attributes["y"] = pol2cart(
+                        attributes["angle"], attributes["distance"]
                     )
 
                 observation_dict = dict(
